<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.


/**
 * Prints a particular instance of videochat
 *
 * You can have a rather longer description of the file as well,
 * if you like, and it can span multiple lines.
 *
 * @package   mod_videochat
 * @copyright 2010 Your Name
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

/// (Replace videochat with the name of your module and remove this line)

require_once(dirname(dirname(dirname(__FILE__))).'/config.php');
require_once(dirname(__FILE__).'/lib.php');

$id = optional_param('id', 0, PARAM_INT); // course_module ID, or
$n  = optional_param('n', 0, PARAM_INT);  // videochat instance ID - it should be named as the first character of the module
$video  = optional_param('video', 0, PARAM_INT);  // videochat instance ID - it should be named as the first character of the module

if ($id) {
	$cm         = get_coursemodule_from_id('videochat', $id, 0, false, MUST_EXIST);
	$course     = $DB->get_record('course', array('id' => $cm->course), '*', MUST_EXIST);
	$videochat  = $DB->get_record('videochat', array('id' => $cm->instance), '*', MUST_EXIST);
} elseif ($n) {
	$videochat  = $DB->get_record('videochat', array('id' => $n), '*', MUST_EXIST);
	$course     = $DB->get_record('course', array('id' => $videochat->course), '*', MUST_EXIST);
	$cm         = get_coursemodule_from_instance('videochat', $videochat->id, $course->id, false, MUST_EXIST);
} else {
	error('You must specify a course_module ID or an instance ID');
}

require_login($course, true, $cm);
$context = get_context_instance(CONTEXT_MODULE, $cm->id);
$PAGE->set_context($context);

if ($video == 0) {

	/// Print the page header
	add_to_log($course->id, 'videochat', 'view', "view.php?id=$cm->id", $videochat->name, $cm->id);

	$PAGE->set_url('/mod/videochat/view.php', array('id' => $cm->id));
	$accessdata = get_user_access_sitewide($_SESSION['USER']->id);
	$PAGE->set_title($course->fullname.': '.get_string('moduletitle', 'videochat'));
	$PAGE->set_heading($course->shortname);
	$PAGE->set_button(update_module_button($cm->id, $course->id, get_string('modulename', 'videochat')));

	// other things you may want to set - remove if not needed
	//$PAGE->set_cacheable(false);
	//$PAGE->set_focuscontrol('some-html-id');

	// Output starts here
	echo $OUTPUT->header();

	if (has_capability('mod/videochat:view', $context)) {
		// Replace the following lines with you own code
		//echo $OUTPUT->heading('Video Consultation room name '.$videochat->name.$course->shortname.$id.', '.$USER->id.', '.$USER->username);
		echo $OUTPUT->heading($videochat->name);
		if ($videochat->open == '1') {		
			if ($videochat->intro) {
				echo $OUTPUT->box(format_module_intro('videochat', $videochat, $cm->id), 'generalbox', 'intro');
			}

			/// Print the main part of the page
			echo $OUTPUT->box_start('generalbox', 'enterlink');
			if ($USER->id == $videochat->adminuserid) {
				$params['id'] = $id;
				$params['video'] = '1';
				//$params['key'] = md5($CFG->adminkey.$videochat->name);
			} else {
				$params['id'] = $id;
				$params['video'] = '1';
			}
			$link = new moodle_url('/mod/videochat/view.php', $params);
			$action = new popup_action('click', $link, "popup", array('height' => 500, 'width' => 700));
			echo '<h2 align = "center">';
			echo $OUTPUT->action_link($link, get_string('enter', 'videochat'), $action, array('title'=>get_string('modulename', 'videochat')));
			echo '</h2><p>Clicking link above should open application in a new window. If application does not open, disable popup blockers for this site or right click and open in new tab.</p>';
		} else {
			echo $OUTPUT->box_start('generalbox', 'enterlink');
			echo '<p>The room currently closed ';
			echo '</p>';
		}
		echo $OUTPUT->box_end();
	} else {
		echo $OUTPUT->box_start('generalbox', 'notallowenter');
		echo '<p>'.get_string('notallowenter', 'videochat').'</p>';
		echo $OUTPUT->box_end();
	}

	// Finish the page
	echo $OUTPUT->footer();
} else {
	
	$rtmp_server = $CFG->rtmp_host3;
	$rtmp_amf = $CFG->rtmp_amf3;
	$rtmfp_server = $CFG->rtmfp_host3;

	$username = $USER->username;
	$r = $videochat->name;
	
	setcookie("user_name",urlencode($username),time()+86400);
	setcookie("room_name",$r,time()+86400);
	setcookie("rtmp_server",$rtmp_server,time()+86400);
	setcookie("rtmp_amf",$rtmp_amf,time()+86400);
	setcookie("rtmfp_server",$rtmfp_server,time()+86400);
	setcookie("bufferLive",$CFG->bufferLive3,time()+86400);
	setcookie("bufferFull",$CFG->bufferFull3,time()+86400);
	setcookie("bufferLivePlayback",$CFG->bufferLivePlayback3,time()+86400);
	setcookie("bufferFullPlayback",$CFG->bufferFullPlayback3,time()+86400);
	setcookie("adServer",$CFG->adServer3,time()+86400);
	setcookie("adsInterval",$CFG->adsInterval3,time()+86400);
	setcookie("adsTimeout",$CFG->adsTimeout3,time()+86400);
	setcookie("disableBandwidthDetection",'0',time()+86400);
	if ($CFG->disableBandwidthDetection3 != '0') setcookie("disableBandwidthDetection",'1',time()+86400);
	setcookie("limitByBandwidth",'0',time()+86400);
	if ($CFG->limitByBandwidth3 != '0') setcookie("limitByBandwidth",'1',time()+86400);
	setcookie("autosnapshots",'0',time()+86400);
	if ($CFG->autoSnapshots3 != '0') setcookie("autosnapshots",'1',time()+86400);

	setcookie("camWidth",$videochat->camwidth,time()+86400);
	setcookie("camHeight",$videochat->camheight,time()+86400);
	setcookie("camFPS",$videochat->camfps,time()+86400);
	setcookie("micRate",$videochat->micrate,time()+86400);
	setcookie("camBandwidth",$videochat->cambandwidth,time()+86400);
	setcookie("camMaxBandwidth",$videochat->cambandmaxwidth,time()+86400);
	setcookie("welcome",$videochat->welcome,time()+86400);
	setcookie("verboselevel",$videochat->verboselevel,time()+86400);
	setcookie("snapshotstime",$videochat->snapshotstime,time()+86400);
	setcookie("disableEmoticons",$videochat->disableemoticons,time()+86400);
	setcookie("filterregex",$videochat->filterregex,time()+86400);
	setcookie("filterreplace",$videochat->filterreplace,time()+86400);
	if (has_capability('mod/videochat:configureconnection', $context)) {
		setcookie("configureconnection",'1',time()+86400);
	} else {
		setcookie("configureconnection",'0',time()+86400);
	}
	if (has_capability('mod/videochat:showcamsettings', $context)) {
		setcookie("showCamSettings",'1',time()+86400);
	} else {
		setcookie("showCamSettings",'0',time()+86400);
	}
	if (has_capability('mod/videochat:showtimer', $context)) {
		setcookie("showtimer",'0',time()+86400);
	} else {
		setcookie("showtimer",'1',time()+86400);
	}
	if (has_capability('mod/videochat:configuresource', $context)) {
		setcookie("configureSource",'1',time()+86400);
	} else {
		setcookie("configureSource",'0',time()+86400);
	}
	if (has_capability('mod/videochat:disablevideo', $context)) {
		setcookie("disableVideo",'0',time()+86400);
	} else {
		setcookie("disableVideo",'1',time()+86400);
	}
	if (has_capability('mod/videochat:disablesound', $context)) {
		setcookie("disableSound",'0',time()+86400);
	} else {
		setcookie("disableSound",'1',time()+86400);
	}
	if (has_capability('mod/videochat:requestsnapshot', $context)) {
		setcookie("requestsnapshot",'1',time()+86400);
	} else {
		setcookie("requestsnapshot",'0',time()+86400);
	}
	if (has_capability('mod/videochat:enablesoundfx', $context)) {
		setcookie("enablesoundfx",'1',time()+86400);
	} else {
		setcookie("enablesoundfx",'0',time()+86400);
	}
	if (has_capability('mod/videochat:enablebuzz', $context)) {
		setcookie("enablebuzz",'1',time()+86400);
	} else {
		setcookie("enablebuzz",'0',time()+86400);
	}
	if (has_capability('mod/videochat:enablenext', $context)) {
		setcookie("enablenext",'1',time()+86400);
	} else {
		setcookie("enablenext",'0',time()+86400);
	}
	if (has_capability('mod/videochat:enableserver', $context)) {
		setcookie("enableserver",'1',time()+86400);
	} else {
		setcookie("enableserver",'0',time()+86400);
	}
	if (has_capability('mod/videochat:enableP2P', $context)) {
		setcookie("enableP2P",'1',time()+86400);
	} else {
		setcookie("enableP2P",'0',time()+86400);
	}

	$swfurl="2wvc.swf";
	$bgcolor="#333333";
	$baseurl="";
	$wmode="transparent";
?>
<html lang="en">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-2" />
<title><?php echo $r;?>2 Way Video Chat</title>
<style type="text/css">
<!--
BODY
{
	margin:0px;
	background-color: #333;
}

#2wayvideochat
{
	width:100%;
	height:700px;
	z-index:0;
	vertical-align: middle;
	text-align: center;
}
-->
</style>
</head>
<BODY>
<CENTER>

<SCRIPT language="JavaScript">
//the code below allows activating certain functions from javascript
function getFlashMovie(movieName) {
  var isIE = navigator.appName.indexOf("Microsoft") != -1;
  return (isIE) ? window[movieName] : document[movieName];
}

//flash = flash html object name (ie "videowhisper_chat")
//action = next / snapshot / snapshot_self / buzz / p2p_toggle
function videowhisperCallActionscript(flash, action) 
{
    var movie = getFlashMovie(flash);
	movie.videowhisperToActionscript(action);
}
</SCRIPT>

<div id="2wayvideochat">
<object width="1000" height="700">
<param name="movie" id="movie" value="<?=$swfurl?>" /><param name="bgcolor" value="<?=$bgcolor?>" /><param name="salign" value="lt" /><param name="scale" value="noscale" /><param name="allowFullScreen" value="true" /><param name="allowscriptaccess" value="always" /> <param name="base" value="<?=$baseurl?>" /> <param name="wmode" value="<?=$wmode?>" /> <embed name="videowhisper_chat" width="1000" height="700" scale="noscale" salign="lt" src="<?=$swfurl?>" bgcolor="<?=$bgcolor?>" base="<?=$baseurl?>" type="application/x-shockwave-flash" allowscriptaccess="always" allowfullscreen="true" wmode="<?=$wmode?>"></embed>
</object>
<noscript>
<p align=center>VideoWhisper  <a href="http://www.videowhisper.com/?p=2+Way+Video+Chat"><strong>Video Chat Script</strong></a></p>
<p align="center"><strong>This content requires the Adobe Flash Player:
<a href="http://get.adobe.com/flashplayer/">Get Latest Flash</a></strong>!</p>
</noscript>
</div>
</CENTER>
</BODY>
</html>

<?php
}